"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .filteroperator import FilterOperator
from polar_sdk.types import BaseModel
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


ValueTypedDict = TypeAliasType("ValueTypedDict", Union[str, int, bool])


Value = TypeAliasType("Value", Union[str, int, bool])


class FilterClauseTypedDict(TypedDict):
    property: str
    operator: FilterOperator
    value: ValueTypedDict


class FilterClause(BaseModel):
    property: str

    operator: FilterOperator

    value: Value
