"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customersubscriptioncancel import (
    CustomerSubscriptionCancel,
    CustomerSubscriptionCancelTypedDict,
)
from .customersubscriptionupdateproduct import (
    CustomerSubscriptionUpdateProduct,
    CustomerSubscriptionUpdateProductTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CustomerSubscriptionUpdateTypedDict = TypeAliasType(
    "CustomerSubscriptionUpdateTypedDict",
    Union[
        CustomerSubscriptionUpdateProductTypedDict, CustomerSubscriptionCancelTypedDict
    ],
)


CustomerSubscriptionUpdate = TypeAliasType(
    "CustomerSubscriptionUpdate",
    Union[CustomerSubscriptionUpdateProduct, CustomerSubscriptionCancel],
)
