"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LicenseKeyStatus(str, Enum):
    GRANTED = "granted"
    REVOKED = "revoked"
    DISABLED = "disabled"
