"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationsocialplatforms import OrganizationSocialPlatforms
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class OrganizationSocialLinkTypedDict(TypedDict):
    platform: OrganizationSocialPlatforms
    url: str
    r"""The URL to the organization profile"""


class OrganizationSocialLink(BaseModel):
    platform: OrganizationSocialPlatforms

    url: str
    r"""The URL to the organization profile"""
