"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .checkoutlinkupdate import CheckoutLinkUpdate, CheckoutLinkUpdateTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CheckoutLinksUpdateRequestTypedDict(TypedDict):
    id: str
    r"""The checkout link ID."""
    checkout_link_update: CheckoutLinkUpdateTypedDict


class CheckoutLinksUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The checkout link ID."""

    checkout_link_update: Annotated[
        CheckoutLinkUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
