"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PledgeType(str, Enum):
    PAY_UPFRONT = "pay_upfront"
    PAY_ON_COMPLETION = "pay_on_completion"
    PAY_DIRECTLY = "pay_directly"
