"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SubscriptionProrationBehavior(str, Enum):
    INVOICE = "invoice"
    PRORATE = "prorate"
