"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meterupdate import MeterUpdate, MeterUpdateTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class MetersUpdateRequestTypedDict(TypedDict):
    id: str
    r"""The meter ID."""
    meter_update: MeterUpdateTypedDict


class MetersUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The meter ID."""

    meter_update: Annotated[
        MeterUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
