"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class RefundReason(str, Enum):
    DUPLICATE = "duplicate"
    FRAUDULENT = "fraudulent"
    CUSTOMER_REQUEST = "customer_request"
    SERVICE_DISRUPTION = "service_disruption"
    SATISFACTION_GUARANTEE = "satisfaction_guarantee"
    OTHER = "other"
