"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subtype import SubType
from enum import Enum
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class TokenType(str, Enum):
    ACCESS_TOKEN = "access_token"
    REFRESH_TOKEN = "refresh_token"


class IntrospectTokenResponseTypedDict(TypedDict):
    active: bool
    client_id: str
    token_type: TokenType
    scope: str
    sub_type: SubType
    sub: str
    aud: str
    iss: str
    exp: int
    iat: int


class IntrospectTokenResponse(BaseModel):
    active: bool

    client_id: str

    token_type: TokenType

    scope: str

    sub_type: SubType

    sub: str

    aud: str

    iss: str

    exp: int

    iat: int
