"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ProductBillingType(str, Enum):
    ONE_TIME = "one_time"
    RECURRING = "recurring"
