"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class Func(str, Enum):
    SUM = "sum"
    MAX = "max"
    MIN = "min"
    AVG = "avg"


class PropertyAggregationTypedDict(TypedDict):
    func: Func
    property: str


class PropertyAggregation(BaseModel):
    func: Func

    property: str
