"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .metricperiod import MetricPeriod, MetricPeriodTypedDict
from .metrics import Metrics, MetricsTypedDict
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class MetricsResponseTypedDict(TypedDict):
    r"""Metrics response schema."""

    periods: List[MetricPeriodTypedDict]
    r"""List of data for each timestamp."""
    metrics: MetricsTypedDict


class MetricsResponse(BaseModel):
    r"""Metrics response schema."""

    periods: List[MetricPeriod]
    r"""List of data for each timestamp."""

    metrics: Metrics
