"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customersessioncustomerexternalidcreate import (
    CustomerSessionCustomerExternalIDCreate,
    CustomerSessionCustomerExternalIDCreateTypedDict,
)
from .customersessioncustomeridcreate import (
    CustomerSessionCustomerIDCreate,
    CustomerSessionCustomerIDCreateTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CustomerSessionsCreateCustomerSessionCreateTypedDict = TypeAliasType(
    "CustomerSessionsCreateCustomerSessionCreateTypedDict",
    Union[
        CustomerSessionCustomerIDCreateTypedDict,
        CustomerSessionCustomerExternalIDCreateTypedDict,
    ],
)


CustomerSessionsCreateCustomerSessionCreate = TypeAliasType(
    "CustomerSessionsCreateCustomerSessionCreate",
    Union[CustomerSessionCustomerIDCreate, CustomerSessionCustomerExternalIDCreate],
)
