"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BenefitType(str, Enum):
    CUSTOM = "custom"
    DISCORD = "discord"
    GITHUB_REPOSITORY = "github_repository"
    DOWNLOADABLES = "downloadables"
    LICENSE_KEYS = "license_keys"
