"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .checkoutlinkcreateproduct import (
    CheckoutLinkCreateProduct,
    CheckoutLinkCreateProductTypedDict,
)
from .checkoutlinkcreateproductprice import (
    CheckoutLinkCreateProductPrice,
    CheckoutLinkCreateProductPriceTypedDict,
)
from .checkoutlinkcreateproducts import (
    CheckoutLinkCreateProducts,
    CheckoutLinkCreateProductsTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CheckoutLinksCreateCheckoutLinkCreateTypedDict = TypeAliasType(
    "CheckoutLinksCreateCheckoutLinkCreateTypedDict",
    Union[
        CheckoutLinkCreateProductPriceTypedDict,
        CheckoutLinkCreateProductTypedDict,
        CheckoutLinkCreateProductsTypedDict,
    ],
)


CheckoutLinksCreateCheckoutLinkCreate = TypeAliasType(
    "CheckoutLinksCreateCheckoutLinkCreate",
    Union[
        CheckoutLinkCreateProductPrice,
        CheckoutLinkCreateProduct,
        CheckoutLinkCreateProducts,
    ],
)
