"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .authorizationcodetokenrequest import (
    AuthorizationCodeTokenRequest,
    AuthorizationCodeTokenRequestTypedDict,
)
from .refreshtokenrequest import RefreshTokenRequest, RefreshTokenRequestTypedDict
from typing import Union
from typing_extensions import TypeAliasType


Oauth2RequestTokenRequestBodyTypedDict = TypeAliasType(
    "Oauth2RequestTokenRequestBodyTypedDict",
    Union[RefreshTokenRequestTypedDict, AuthorizationCodeTokenRequestTypedDict],
)


Oauth2RequestTokenRequestBody = TypeAliasType(
    "Oauth2RequestTokenRequestBody",
    Union[RefreshTokenRequest, AuthorizationCodeTokenRequest],
)
