"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customerproduct import CustomerProduct, CustomerProductTypedDict
from .organization import Organization, OrganizationTypedDict
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class CustomerOrganizationTypedDict(TypedDict):
    r"""Schema of an organization and related data for customer portal."""

    organization: OrganizationTypedDict
    products: List[CustomerProductTypedDict]


class CustomerOrganization(BaseModel):
    r"""Schema of an organization and related data for customer portal."""

    organization: Organization

    products: List[CustomerProduct]
