"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, SecurityMetadata
from typing_extensions import Annotated, TypedDict


class CustomerPortalCustomersUpdateSecurityTypedDict(TypedDict):
    customer_session: str


class CustomerPortalCustomersUpdateSecurity(BaseModel):
    customer_session: Annotated[
        str,
        FieldMetadata(
            security=SecurityMetadata(
                scheme=True,
                scheme_type="http",
                sub_type="bearer",
                field_name="Authorization",
            )
        ),
    ]
