"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomerCancellationReason(str, Enum):
    CUSTOMER_SERVICE = "customer_service"
    LOW_QUALITY = "low_quality"
    MISSING_FEATURES = "missing_features"
    SWITCHED_SERVICE = "switched_service"
    TOO_COMPLEX = "too_complex"
    TOO_EXPENSIVE = "too_expensive"
    UNUSED = "unused"
    OTHER = "other"
