"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CustomerSubscriptionSortProperty(str, Enum):
    STARTED_AT = "started_at"
    MINUS_STARTED_AT = "-started_at"
    AMOUNT = "amount"
    MINUS_AMOUNT = "-amount"
    STATUS = "status"
    MINUS_STATUS = "-status"
    ORGANIZATION = "organization"
    MINUS_ORGANIZATION = "-organization"
    PRODUCT = "product"
    MINUS_PRODUCT = "-product"
