"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CheckoutLinkSortProperty(str, Enum):
    CREATED_AT = "created_at"
    MINUS_CREATED_AT = "-created_at"
    LABEL = "label"
    MINUS_LABEL = "-label"
    SUCCESS_URL = "success_url"
    MINUS_SUCCESS_URL = "-success_url"
    ALLOW_DISCOUNT_CODES = "allow_discount_codes"
    MINUS_ALLOW_DISCOUNT_CODES = "-allow_discount_codes"
