"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class MeterQuantityTypedDict(TypedDict):
    timestamp: datetime
    r"""The timestamp for the current period."""
    quantity: float
    r"""The quantity for the current period."""


class MeterQuantity(BaseModel):
    timestamp: datetime
    r"""The timestamp for the current period."""

    quantity: float
    r"""The quantity for the current period."""
