"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .checkoutupdatepublic import CheckoutUpdatePublic, CheckoutUpdatePublicTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CheckoutsClientUpdateRequestTypedDict(TypedDict):
    client_secret: str
    r"""The checkout session client secret."""
    checkout_update_public: CheckoutUpdatePublicTypedDict


class CheckoutsClientUpdateRequest(BaseModel):
    client_secret: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The checkout session client secret."""

    checkout_update_public: Annotated[
        CheckoutUpdatePublic,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
