"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class CustomerPaymentMethodCreateTypedDict(TypedDict):
    confirmation_token_id: str
    set_default: bool
    return_url: str


class CustomerPaymentMethodCreate(BaseModel):
    confirmation_token_id: str

    set_default: bool

    return_url: str
